@@ -600,16 +600,18 @@ def cp(src, dst, method='auto', **kwargs):
         logger.error('Method %s is not a valid copying method!', method)
         raise
 
-def _cp_xrdcp(src, dst, n_retries=N_COPY_RETRIES, create_parent_directory=True, verbose=True):
+def _cp_xrdcp(src, dst, n_retries=N_COPY_RETRIES, create_parent_directory=True, verbose=True, force=False):
     cmd = [ 'xrdcp', src, dst ]
     if not verbose: cmd.insert(1, '-s')
     if create_parent_directory: cmd.insert(1, '-p')
+    if force: cmd.insert(1, '-f')
     run_command(cmd, n_retries=n_retries)
 
-def _cp_gfal(src, dst, n_retries=N_COPY_RETRIES, create_parent_directory=True, verbose=True):
+def _cp_gfal(src, dst, n_retries=N_COPY_RETRIES, create_parent_directory=True, verbose=True, force=False):
     cmd = [ 'gfal-copy', '-t', '180', src, dst ]
     if create_parent_directory: cmd.insert(1, '-p')
     if verbose: cmd.insert(1, '-v')
+    if force: cmd.insert(1, '-f')
     run_command(cmd, n_retries=n_retries)
 
 def cp_to_se(src, dst, **kwargs):
